#[repr(u32)]pub enum FindSynthTarget {
Enum = 0,
Rewrite = 1,
RewriteUnsound = 2,
RewriteInput = 3,
Query = 4,
Last = 5,
}Expand description
Find synthesis targets, used as an argument to Solver::findSynth. These specify various kinds of terms that can be found by this method.
Variants