#[repr(u32)]pub enum LearnedLitType {
PreprocessSolved = 0,
Preprocess = 1,
Input = 2,
Solvable = 3,
ConstantProp = 4,
Internal = 5,
Unknown = 6,
Last = 7,
}Expand description
Types of learned literals.
Specifies categories of literals learned for the method Solver::getLearnedLiterals.
Note that a literal may conceptually belong to multiple categories. We classify literals based on the first criteria in this list that they meet.
Variants
PreprocessSolved = 0
Preprocess = 1
Input = 2
Solvable = 3
ConstantProp = 4
Internal = 5
Unknown = 6
Last = 7