#[repr(u32)]pub enum RoundingMode {
RoundNearestTiesToEven = 0,
RoundTowardPositive = 1,
RoundTowardNegative = 2,
RoundTowardZero = 3,
RoundNearestTiesToAway = 4,
Last = 5,
}Expand description
Rounding modes for floating-point numbers.
For many floating-point operations, infinitely precise results may not be representable with the number of available bits. Thus, the results are rounded in a certain way to one of the representable floating-point numbers.
\verbatim embed:rst:leading-asterisk
These rounding modes directly follow the SMT-LIB theory for floating-point
arithmetic, which in turn is based on IEEE Standard 754 :cite:IEEE754.
The rounding modes are specified in Sections 4.3.1 and 4.3.2 of the IEEE
Standard 754.
\endverbatim
Variants
RoundNearestTiesToEven = 0
RoundTowardPositive = 1
RoundTowardNegative = 2
RoundTowardZero = 3
RoundNearestTiesToAway = 4
Last = 5