SortKind

Enum SortKind 

#[repr(i32)]
pub enum SortKind {
Show 23 variants InternalSortKind = -2, UndefinedSortKind = -1, NullSort = 0, AbstractSort = 1, ArraySort = 2, BagSort = 3, BooleanSort = 4, BitvectorSort = 5, DatatypeSort = 6, FiniteFieldSort = 7, FloatingpointSort = 8, FunctionSort = 9, IntegerSort = 10, RealSort = 11, ReglanSort = 12, RoundingmodeSort = 13, SequenceSort = 14, SetSort = 15, StringSort = 16, TupleSort = 17, NullableSort = 18, UninterpretedSort = 19, LastSortKind = 20,
}
The kind of a cvc5 Sort.

\internal

Note that the API type cvc5::SortKind roughly corresponds to cvc5::internal::Kind, but is a different type. It hides internal kinds that should not be exported to the API, and maps all kinds that we want to export to its corresponding internal kinds. The underlying type of cvc5::Kind must be signed (to enable range checks for validity). The size of this type depends on the size of cvc5::internal::Kind (NodeValue::NBITS_KIND, currently 10 bits, see expr/node_value.h).

Variants



InternalSortKind = -2



UndefinedSortKind = -1



NullSort = 0



AbstractSort = 1



ArraySort = 2



BagSort = 3



BooleanSort = 4



BitvectorSort = 5



DatatypeSort = 6



FiniteFieldSort = 7



FloatingpointSort = 8



FunctionSort = 9



IntegerSort = 10



RealSort = 11



ReglanSort = 12



RoundingmodeSort = 13



SequenceSort = 14



SetSort = 15



StringSort = 16



TupleSort = 17



NullableSort = 18



UninterpretedSort = 19



LastSortKind = 20