block_model

Function block_model 

pub unsafe extern "C" fn block_model(
    cvc5: *mut Solver,
    mode: BlockModelsMode,
)
Block the current model. Can be called only if immediately preceded by a SAT or INVALID query.

SMT-LIB:

\verbatim embed:rst:leading-asterisk .. code:: smtlib

(block-model)

Requires enabling option :ref:produce-models <lbl-option-produce-models>. \endverbatim

@warning This function is experimental and may change in future versions.

@param cvc5 The solver instance. @param mode The mode to use for blocking.