close_output

Function close_output 

pub unsafe extern "C" fn close_output(
    cvc5: *mut Solver,
    filename: *const c_char,
)
Close output file configured for an output tag via cvc5_get_output().

@note This is required before reading the file.

@warning This function is experimental and may change in future versions.

@param cvc5 The solver instance. @param filename The file to close.