dt_cons_decl_to_string

Function dt_cons_decl_to_string 

pub unsafe extern "C" fn dt_cons_decl_to_string(
    decl: DatatypeConstructorDecl,
) -> *const c_char
Get a string representation of a given constructor declaration. @param decl The datatype constructor declaration. @return The string representation. @note The returned char* pointer is only valid until the next call to this function.