pub unsafe extern "C" fn dt_decl_get_num_constructors(
decl: DatatypeDecl,
) -> usizeExpand description
Get the number of constructors for a given Datatype declaration. @param decl The datatype declaration. @return The number of constructors.
pub unsafe extern "C" fn dt_decl_get_num_constructors(
decl: DatatypeDecl,
) -> usizeGet the number of constructors for a given Datatype declaration. @param decl The datatype declaration. @return The number of constructors.