dt_decl_release

Function dt_decl_release 

pub unsafe extern "C" fn dt_decl_release(decl: DatatypeDecl)
Release copy of datatype declaration, decrements reference counter of decl.

@param decl The datatype declaration to release.

@note This step is optional and allows users to release resources in a more fine-grained manner. Further, any API function that returns a Cvc5DatatypeDecl returns a copy that is owned by the callee of the function and thus, can be released.