dt_get_constructor

Function dt_get_constructor 

pub unsafe extern "C" fn dt_get_constructor(
    dt: Datatype,
    idx: usize,
) -> DatatypeConstructor
Get the datatype constructor of a given datatype at a given index. @param dt The datatype. @param idx The index of the datatype constructor to return. @return The datatype constructor with the given index.