get_option

Function get_option 

pub unsafe extern "C" fn get_option(
    cvc5: *mut Solver,
    option: *const c_char,
) -> *const c_char
Get the value of a given option.

SMT-LIB:

\verbatim embed:rst:leading-asterisk .. code:: smtlib

(get-option <keyword>)

\endverbatim

@param cvc5 The solver instance. @param option The option for which the value is queried. @return A string representation of the option value. @note The returned char* pointer is only valid until the next call to this function.