get_statistics

Function get_statistics 

pub unsafe extern "C" fn get_statistics(
    cvc5: *mut Solver,
) -> Statistics
Get a snapshot of the current state of the statistic values of this solver. The returned object is completely decoupled from the solver and will not change when the solver is used again. @param cvc5 The solver instance. @return A snapshot of the current state of the statistic values.