get_version

Function get_version 

pub unsafe extern "C" fn get_version(
    cvc5: *mut Solver,
) -> *const c_char
Get a string representation of the version of this solver. @param cvc5 The solver instance. @return The version string. @note The returned char* pointer is only valid until the next call to this function.