mk_ff_sort

Function mk_ff_sort 

pub unsafe extern "C" fn mk_ff_sort(
    tm: *mut TermManager,
    size: *const c_char,
    base: u32,
) -> Sort
Create a finite-field sort from a given string of base n.

@param tm The term manager instance. @param size The modulus of the field. Must be prime. @param base The base of the string representation of size. @return The finite-field sort.