mk_integer

Function mk_integer 

pub unsafe extern "C" fn mk_integer(
    tm: *mut TermManager,
    s: *const c_char,
) -> Term
Create an integer constant from a string. @param tm The term manager instance. @param s The string representation of the constant, may represent an integer (e.g., “123”). @return A constant of sort Integer assuming s represents an integer)