mk_param_sort

Function mk_param_sort 

pub unsafe extern "C" fn mk_param_sort(
    tm: *mut TermManager,
    symbol: *const c_char,
) -> Sort
Create a sort parameter. @warning This function is experimental and may change in future versions. @param tm The term manager instance. @param symbol The name of the sort, may be NULL. @return The sort parameter.