pub unsafe extern "C" fn mk_record_sort(
tm: *mut TermManager,
size: usize,
names: *mut *const c_char,
sorts: *const Sort,
) -> SortExpand description
Create a record sort @warning This function is experimental and may change in future versions. @param tm The term manager instance. @param size The number of fields of the record. @param names The names of the fields of the record. @param sorts The sorts of the fields of the record. @return The record sort.