proof_copy

Function proof_copy 

pub unsafe extern "C" fn proof_copy(proof: Proof) -> Proof
Make copy of proof, increases reference counter of proof.

@param proof The proof to copy. @return The same proof with its reference count increased by one.

@note This step is optional and allows users to manage resources in a more fine-grained manner.