proof_release

Function proof_release 

pub unsafe extern "C" fn proof_release(proof: Proof)
Release copy of proof, decrements reference counter of proof.

@param proof The proof to release.

@note This step is optional and allows users to release resources in a more fine-grained manner. Further, any API function that returns a copy that is owned by the callee of the function and thus, can be released.