result_copy

Function result_copy 

pub unsafe extern "C" fn result_copy(result: Result) -> Result
Make copy of result, increases reference counter of result.

@param result The result to copy. @return The same result with its reference count increased by one.

@note This step is optional and allows users to manage resources in a more fine-grained manner.