result_is_null

Function result_is_null 

pub unsafe extern "C" fn result_is_null(result: Result) -> bool
Determine if a given result is empty (a nullary result) and not an actual result returned from a cvc5_check_sat() (and friends) query. @param result The result. @return True if the given result is a nullary result.