result_release

Function result_release 

pub unsafe extern "C" fn result_release(result: Result)
Release copy of result, decrements reference counter of result.

@param result The result to release.

@note This step is optional and allows users to release resources in a more fine-grained manner. Further, any API function that returns a copy that is owned by the callee of the function and thus, can be released.