sort_array_get_index_sort

Function sort_array_get_index_sort 

pub unsafe extern "C" fn sort_array_get_index_sort(sort: Sort) -> Sort
Get the index sort of a given array sort. @param sort The sort. @return The array index sort of an array sort.