sort_copy

Function sort_copy 

pub unsafe extern "C" fn sort_copy(sort: Sort) -> Sort
Make copy of sort, increases reference counter of sort.

@param sort The sort to copy. @return The same sort with its reference count increased by one.

@note This step is optional and allows users to manage resources in a more fine-grained manner.