sort_is_boolean

Function sort_is_boolean 

pub unsafe extern "C" fn sort_is_boolean(sort: Sort) -> bool
Determine if given sort is the Boolean sort (SMT-LIB: Bool). @param sort The sort. @return True if given sort is the Boolean sort.