sort_is_ff

Function sort_is_ff 

pub unsafe extern "C" fn sort_is_ff(sort: Sort) -> bool
Determine if given sort is a finite field sort. @param sort The sort. @return True if the sort is a finite field sort.