sort_is_integer

Function sort_is_integer 

pub unsafe extern "C" fn sort_is_integer(sort: Sort) -> bool
Determine if given sort is the integer sort (SMT-LIB: Int). @param sort The sort. @return True if given sort is the integer sort.