sort_is_rm

Function sort_is_rm 

pub unsafe extern "C" fn sort_is_rm(sort: Sort) -> bool
Determine if given sort is the rounding mode sort (SMT-LIB: Cvc5RoundingMode). @param sort The sort. @return True if given sort is the rounding mode sort.