sort_is_string

Function sort_is_string 

pub unsafe extern "C" fn sort_is_string(sort: Sort) -> bool
Determine if given sort is the string sort (SMT-LIB: String). @param sort The sort. @return True if given sort is the string sort.