pub unsafe extern "C" fn sort_is_uninterpreted_sort_constructor(
sort: Sort,
) -> boolExpand description
Determine if given sort is an uninterpreted sort constructor.
An uninterpreted sort constructor has arity > 0 and can be instantiated to construct uninterpreted sorts with given sort parameters.
@param sort The sort. @return True if given sort is of sort constructor kind.