pub unsafe extern "C" fn sort_release(sort: Sort)Expand description
Release copy of sort, decrements reference counter of sort.
@param sort The sort to release.
@note This step is optional and allows users to release resources in a more fine-grained manner. Further, any API function that returns a Cvc5Sort returns a copy that is owned by the callee of the function and thus, can be released.