stat_get_histogram

Function stat_get_histogram 

pub unsafe extern "C" fn stat_get_histogram(
    stat: Stat,
    keys: *mut *mut *const c_char,
    values: *mut *mut u64,
    size: *mut usize,
)
Get the value of a histogram statistic. @param stat The statistic. @param keys The resulting arrays with the keys of the statistic, map to the values given in the resulting values array.. @param values The resulting arrays with the values of the statistic. @param size The size of the resulting keys/values arrays.