stats_to_string

Function stats_to_string 

pub unsafe extern "C" fn stats_to_string(
    stat: Statistics,
) -> *const c_char
Get a string representation of a given statistics object. @param stat The statistics. @return The string representation. @note The returned char* pointer is only valid until the next call to this function.