synth_result_has_solution

Function synth_result_has_solution 

pub unsafe extern "C" fn synth_result_has_solution(
    result: SynthResult,
) -> bool
Determine if the given result is from a synthesis query that has a solution. @param result The result. @return True if the synthesis query has a solution.