synth_result_to_string

Function synth_result_to_string 

pub unsafe extern "C" fn synth_result_to_string(
    result: SynthResult,
) -> *const c_char
Get the string representation of a given result. @param result The result. @return A string representation of the given synthesis result. @note The returned char* pointer is only valid until the next call to this function.