term_copy

Function term_copy 

pub unsafe extern "C" fn term_copy(term: Term) -> Term
Make copy of term, increases reference counter of term.

@param term The term to copy. @return The same term with its reference count increased by one.

@note This step is optional and allows users to manage resources in a more fine-grained manner.