term_get_boolean_value

Function term_get_boolean_value 

pub unsafe extern "C" fn term_get_boolean_value(term: Term) -> bool
Get the value of a Boolean term as a native Boolean value. @note Asserts cvc5_term_is_boolean_value(). @param term The term. @return The representation of a Boolean value as a native Boolean value.