term_get_ff_value

Function term_get_ff_value 

pub unsafe extern "C" fn term_get_ff_value(
    term: Term,
) -> *const c_char
Get the string representation of a finite field value (base 10).

@note Asserts cvc5_term_is_ff_value().

@note Uses the integer representative of smallest absolute value.

@param term The term. @return The string representation of the integer representation of the finite field value. @note The returned char* pointer is only valid until the next call to this function.