term_get_integer_value

Function term_get_integer_value 

pub unsafe extern "C" fn term_get_integer_value(
    term: Term,
) -> *const c_char
Get a string representation of a given integral value. @note Requires that the term is an integral value (see cvc5_term_is_integer_value()). @param term The term. @return The integral term in (decimal) string representation. @note The returned char* pointer is only valid until the next call to this function.