term_get_real_value

Function term_get_real_value 

pub unsafe extern "C" fn term_get_real_value(
    term: Term,
) -> *const c_char
Get a string representation of a given rational value. @note Requires that the term is a rational value (see cvc5_term_is_real_value()). @param term The term. @return The representation of a rational value as a (rational) string. @note The returned char* pointer is only valid until the next call to this function.