term_get_u32string_value

Function term_get_u32string_value 

pub unsafe extern "C" fn term_get_u32string_value(
    term: Term,
) -> *const char32_t
Get the native UTF-32 string representation of a string value. @note Requires that the term is a string value (see cvc5_term_is_string_value()). @note This is not to be confused with cvc5_term_to_string(), which returns some string representation of the term, whatever data it may hold. @param term The term. @return The string term as a native UTF-32 string value.