term_is_const_array

Function term_is_const_array 

pub unsafe extern "C" fn term_is_const_array(term: Term) -> bool
Determine if a given term is a constant array. @param term The term. @return True if the term is a constant array.