term_is_tuple_value

Function term_is_tuple_value 

pub unsafe extern "C" fn term_is_tuple_value(term: Term) -> bool
Determine if a given term is a tuple value. @param term The term. @return True if the term is a tuple value.