pub unsafe extern "C" fn term_is_uint64_value(term: Term) -> boolExpand description
Determine if a given term is an uint64 value. @note This will return true for integer constants and real constants that have integral value. @param term The term. @return True if the term is an integral value that fits within uint64_t.