term_is_uninterpreted_sort_value

Function term_is_uninterpreted_sort_value 

pub unsafe extern "C" fn term_is_uninterpreted_sort_value(
    term: Term,
) -> bool
Determine if a given term is an uninterpreted sort value. @param term The term. @return True if the term is an abstract value.