cmd_invoke

Function cmd_invoke 

pub unsafe extern "C" fn cmd_invoke(
    cmd: Command,
    cvc5: *mut Solver,
    sm: *mut SymbolManager,
) -> *const c_char
Invoke a given command on the solver and symbol manager sm and return any resulting output as a string. @param cmd The command to invoke. @param cvc5 The solver to invoke the command on. @param sm The symbol manager to invoke the command on. @return The output of invoking the command. @note The returned char* pointer is only valid until the next call to this function.