cvc5_parser_next_command

Function cvc5_parser_next_command 

pub unsafe extern "C" fn cvc5_parser_next_command(
    parser: *mut Cvc5InputParser,
    error_msg: *mut *const c_char,
) -> Cvc5Command
Parse and return the next command. Will initialize the logic to “ALL” or the forced logic if no logic is set prior to this point and a command is read that requires initializing the logic.

@param parser The input parser instance. @param error_msg Output parameter for the error message in case of a parse error, NULL if no error occurred. @return The parsed command. NULL if no command was read.