pub unsafe extern "C" fn parser_get_sm(
parser: *mut InputParser,
) -> *mut SymbolManagerExpand description
Get the associated symbol manager of a given parser. @param parser The parser instance. @return The symbol manager.
pub unsafe extern "C" fn parser_get_sm(
parser: *mut InputParser,
) -> *mut SymbolManagerGet the associated symbol manager of a given parser. @param parser The parser instance. @return The symbol manager.