pub type Cvc5Command = *mut cvc5_cmd_t;Expand description
Encapsulation of a command.
Commands are constructed by the input parser and can be invoked on the solver and symbol manager.
pub type Cvc5Command = *mut cvc5_cmd_t;Encapsulation of a command.
Commands are constructed by the input parser and can be invoked on the solver and symbol manager.