pub unsafe extern "C" fn add_plugin(
cvc5: *mut Solver,
plugin: *mut Plugin,
)Expand description
Add plugin to this solver. Its callbacks will be called throughout the lifetime of this solver. @warning This function is experimental and may change in future versions. @param cvc5 The solver instance. @param plugin The plugin to add to this solver.