pub unsafe extern "C" fn dt_decl_to_string(
decl: DatatypeDecl,
) -> *const c_charExpand description
Get a string representation of a given datatype declaration. @param decl The datatype declaration. @return A string representation of the datatype declaration. @note The returned char* pointer is only valid until the next call to this function.