pub unsafe extern "C" fn get_output(
cvc5: *mut Solver,
tag: *const c_char,
filename: *const c_char,
)Expand description
Configure a file to write the output for a given tag.
Tags can be enabled with the output option (and -o <tag> on the command
line). Requires that the given tag is valid.
@note Close file filename before reading via cvc5_close_output().
@warning This function is experimental and may change in future versions.
@param cvc5 The solver instance.
@param tag The output tag.
@param filename The file to write the output to. Use <stdout> to configure
to write to stdout.