pub unsafe extern "C" fn mk_string_from_wchar(
tm: *mut TermManager,
s: *const wchar_t,
) -> TermExpand description
Create a String constant from a wide character string. This function does not support escape sequences as wide character already supports unicode characters. @param tm The term manager instance. @param s The string this constant represents. @return The String constant.
@warning This function is deprecated and replaced by cvc5_mk_string_from_char32(). It will be removed in a future release.