pub unsafe extern "C" fn op_release(op: Op)Expand description
Release copy of operator, decrements reference counter of op.
@param op The op to release.
@note This step is optional and allows users to release resources in a more fine-grained manner. Further, any API function that returns a Cvc5Op returns a copy that is owned by the callee of the function and thus, can be released.