pub unsafe extern "C" fn proof_get_arguments(
proof: Proof,
size: *mut usize,
) -> *const TermExpand description
Get the arguments of the root step of a given proof. @param proof The proof. @param size Output parameter to store the number of resulting argument terms. @return The argument terms.