pub unsafe extern "C" fn sort_is_dt_constructor(sort: Sort) -> bool
Determine if given sort is a datatype constructor sort. @param sort The sort. @return True if given sort is a datatype constructor sort.