pub unsafe extern "C" fn sort_is_predicate(sort: Sort) -> boolExpand description
Determine if given sort is a predicate sort.
A predicate sort is a function sort that maps to the Boolean sort. All predicate sorts are also function sorts.
@param sort The sort. @return True if given sort is a predicate sort.