pub unsafe extern "C" fn sort_is_record(sort: Sort) -> boolExpand description
Determine if given sort is a record sort. @warning This function is experimental and may change in future versions. @param sort The sort. @return True if the sort is a record sort.