pub unsafe extern "C" fn stats_iter_init(
stat: Statistics,
internal: bool,
dflt: bool,
)Expand description
Initialize iteration over the statistics values. By default, only entries that are public and have been set are visible while the others are skipped. @param stat The statistics. @param internal If set to true, internal statistics are shown as well. @param dflt If set to true, defaulted statistics are shown as well.