pub unsafe extern "C" fn term_get_op(term: Term) -> OpExpand description
Get the operator of a term with an operator.
@note Requires that the term has an operator (see cvc5_term_has_op()).
@param term The term. @return The Op used to create the term.