pub unsafe extern "C" fn term_get_sequence_value(
term: Term,
size: *mut usize,
) -> *const TermExpand description
Get a sequence value as an array of terms. @note Asserts cvc5_term_is_sequence_value(). @param term The term. @param size The size of the resulting array. @return The representation of a sequence value as a vector of terms.