pub unsafe extern "C" fn term_get_tuple_value(
term: Term,
size: *mut usize,
) -> *const TermExpand description
Get a tuple value as an array of terms. @note Asserts cvc5_term_is_tuple_value(). @param term The term. @param size The size of the resulting array. @return The representation of a tuple value as an array of terms.