pub unsafe extern "C" fn term_get_uninterpreted_sort_value(
term: Term,
) -> *const c_charExpand description
Get a string representation of an uninterpreted sort value. @note Asserts cvc5_term_is_uninterpreted_sort_value(). @param term The term. @return The representation of an uninterpreted sort value as a string. @note The returned char* pointer is only valid until the next call to this function.