pub unsafe extern "C" fn term_is_integer_value(term: Term) -> boolExpand description
Determine if a given term is an integral value. @param term The term. @return True if the term is an integer constant or a real constant that has an integral value.