pub unsafe extern "C" fn term_is_uint32_value(term: Term) -> boolExpand description
Determine if a given term is an uint32 value. @note This will return true for integer constants and real constants that have integral value. @return True if the term is an integral value and fits within uint32_t.