pub unsafe extern "C" fn term_release(term: Term)Expand description
Release copy of term, decrements reference counter of term.
@param term The term to release.
@note This step is optional and allows users to release resources in a more fine-grained manner. Further, any API function that returns a copy that is owned by the callee of the function and thus, can be released.