pub unsafe extern "C" fn term_substitute_term(
term: Term,
t: Term,
replacement: Term,
) -> TermExpand description
Replace a given term t with term replacement in a given term.
@param term The term.
@param t The term to replace.
@param replacement The term to replace it with.
@return The result of replacing term with replacement in the term.
@note This replacement is applied during a pre-order traversal and only once (it is not run until fixed point).