pub unsafe extern "C" fn parser_set_file_input(
parser: *mut InputParser,
lang: InputLanguage,
filename: *const c_char,
)Expand description
Configure given file as input to a given input parser. @param parser The input parser instance. @param lang the input language (e.g., #CVC5_INPUT_LANGUAGE_SMT_LIB_2_6) @param filename The name of the file to configure.