pub unsafe extern "C" fn parser_set_inc_str_input(
parser: *mut InputParser,
lang: InputLanguage,
name: *const c_char,
)Expand description
Configure that we will be feeding strings to a given input parser via
cvc5_parser_append_inc_str_input() below.
@param parser The input parser instance.
@param lang The input language of the input string.
@param name The name to use as input stream name for error messages.