pub unsafe extern "C" fn parser_set_str_input(
parser: *mut InputParser,
lang: InputLanguage,
input: *const c_char,
name: *const c_char,
)Expand description
Configure a given concrete input string as the input to a given input parser. @param parser The input parser instance. @param lang The input language of the input string. @param input The input string. @param name The name to use as input stream name for error messages.