pub unsafe extern "C" fn sm_get_declared_terms(
sm: *mut SymbolManager,
size: *mut usize,
) -> *const TermExpand description
Get the list of terms that have been declared via declare-fun and
declare-const. These are the terms that are printed in response to a
get-model command.
@param sm The symbol manager instance. @param size The size of the resulting sorts array. @return The declared terms.terms